pub enum ListReport {
Tree(Vec<ListNodeReport>),
List(Vec<String>),
Empty,
}Expand description
Represents the different report formats for the list action.
Variants
Tree(Vec<ListNodeReport>)
Represents a tree-like report format.
List(Vec<String>)
Represents a standard list report format in topological order.
Empty
Represents an empty report format.