pub struct ListOptions { /* private fields */ }Expand description
A struct representing the arguments for listing crates.
This struct is used to pass the necessary arguments for listing crates. It includes the following fields :
path_to_manifest: ACrateDirrepresenting the path to the manifest of the crates.format: AListFormatenum representing the desired format of the output.dependency_sources: AHashSetofDependencySourcerepresenting the sources of the dependencies.
Implementations
Sourceimpl ListOptions
impl ListOptions