pub struct Manifest {
pub manifest_path: AbsolutePath,
pub manifest_data: Option<Document>,
}Expand description
Hold manifest data.
Fields
manifest_path: AbsolutePathPath to Cargo.toml
manifest_data: Option<Document>Strict type of Cargo.toml manifest.
Implementations
Sourceimpl Manifest
impl Manifest
Sourcepub fn manifest_path(&self) -> &AbsolutePath
pub fn manifest_path(&self) -> &AbsolutePath
Returns path to Cargo.toml.
Sourcepub fn load(&mut self) -> Result<(), ManifestError>
pub fn load(&mut self) -> Result<(), ManifestError>
Load manifest from path.
Sourcepub fn package_is(&self) -> Result<bool, ManifestError>
pub fn package_is(&self) -> Result<bool, ManifestError>
Check that the current manifest is the manifest of the package (can also be a virtual workspace).
Sourcepub fn local_is(&self) -> Result<bool, ManifestError>
pub fn local_is(&self) -> Result<bool, ManifestError>
Check that module is local.
The package is defined as local if the publish field is set to `false’ or the registers are specified.