Trait TemplateFiles

pub trait TemplateFiles: Sized + IntoIterator<Item = TemplateFileDescriptor> {
    // Provided method
    fn create_all(
        self,
        path: &Path,
        values: &TemplateValues,
    ) -> Result<(), Error> { ... }
}
Files stored in a template.

Can be iterated over, consuming the owner of the files.

Provided Methods

fn create_all(self, path: &Path, values: &TemplateValues) -> Result<(), Error>

Creates all files in provided path with values for required parameters.

Consumes owner of the files.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors