pub enum WriteMode {
Rewrite,
TomlExtend,
}Expand description
Determines how the template file should be written.
Variants
Rewrite
Overwrites existing files.
TomlExtend
Attempts to extend existing toml files.
If files exists it searches for the same top-level items (tables, values) and replaces them with template defined ones. If file does not exist it creates a new one with contents provided by the template.