pub struct TemplateFileDescriptor { /* private fields */ }Expand description
File descriptor for the template.
Holds raw template data, relative path for the file, and a flag that specifies whether the raw data should be treated as a template.
Implementations